pub enum IntegrityConfig {
Crc16(Crc16),
Crc32(Crc32),
Crc64(Crc64),
SipTag(SipTag),
}Expand description
Packet integrity backend selected by engine configuration.
Variants
Crc16(Crc16)
CRC-16/XMODEM packet integrity.
Crc32(Crc32)
CRC-32/ISO-HDLC packet integrity.
Crc64(Crc64)
CRC-64/ECMA-182 packet integrity.
SipTag(SipTag)
Keyed 128-bit packet integrity tag.
Implementations
Sourceimpl IntegrityConfig
impl IntegrityConfig
Sourcepub const DEFAULT: IntegrityConfig
pub const DEFAULT: IntegrityConfig
Default packet integrity backend used by crate::engine::EngineConfig.
Sourcepub const fn crc16() -> IntegrityConfig
pub const fn crc16() -> IntegrityConfig
Creates the default CRC-16/XMODEM integrity configuration.
Sourcepub const fn crc32() -> IntegrityConfig
pub const fn crc32() -> IntegrityConfig
Creates a CRC-32/ISO-HDLC integrity configuration.
Sourcepub const fn crc64() -> IntegrityConfig
pub const fn crc64() -> IntegrityConfig
Creates a CRC-64/ECMA-182 integrity configuration.
Sourcepub const fn sip_tag() -> IntegrityConfig
pub const fn sip_tag() -> IntegrityConfig
Creates a keyed integrity tag configuration with the library default key.
Sourcepub const fn sip_tag_with_key(key: [u8; 16]) -> IntegrityConfig
pub const fn sip_tag_with_key(key: [u8; 16]) -> IntegrityConfig
Creates a keyed integrity tag configuration with a custom key.