TokioUartFrontend

Struct TokioUartFrontend 

pub struct TokioUartFrontend<T> { /* private fields */ }
Tokio host UART frontend adapter.

T can be a Tokio serial stream, TCP stream used as a UART-like byte stream, or any async byte stream implementing AsyncRead + AsyncWrite + Unpin.

Implementations

Source

impl<T> TokioUartFrontend<T>
where T: AsyncRead + AsyncWrite + Unpin,

pub fn new(io: T) -> Self

Creates a frontend adapter using default MSRT config.

pub fn with_config(io: T, config: EngineConfig) -> Self

Creates a frontend adapter using config.

pub fn peer_state(&self) -> PeerState

Returns the endpoint peer state.

pub const fn io(&self) -> &T

Returns a shared reference to the owned async IO object.

pub fn io_mut(&mut self) -> &mut T

Returns a mutable reference to the owned async IO object.

pub fn into_inner(self) -> T

Consumes the adapter and returns the async IO object.

pub fn connect(&mut self) -> TokioResult<()>

Starts a fresh frontend session.

pub fn disconnect(&mut self)

Drops the active frontend session.

pub fn send(&mut self, message: &[u8]) -> TokioResult<bool>

Queues an application message.

pub async fn receive_available(&mut self) -> TokioResult<usize>

Reads currently available UART bytes and feeds them into MSRT.

pub async fn poll(&mut self) -> TokioResult<UartFrontendEvent>

Polls one frontend event and writes pending UART bytes.

pub async fn tick(&mut self) -> TokioResult<UartFrontendEvent>

Runs receive_available followed by poll.